pub struct AchievementRevealResponse {
pub current_state: Option<String>,
pub kind: Option<String>,
}Expand description
An achievement reveal response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- reveal achievements (response)
Fields
current_state: Option<String>The current state of the achievement for which a reveal was attempted. This might be UNLOCKED if the achievement was already unlocked.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#achievementRevealResponse.