pub struct AchievementSetStepsAtLeastResponse {
pub current_steps: Option<i32>,
pub kind: Option<String>,
pub newly_unlocked: Option<bool>,
}Expand description
An achievement set steps at least response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- set steps at least achievements (response)
Fields
current_steps: Option<i32>The current steps recorded for this incremental achievement.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#achievementSetStepsAtLeastResponse.
newly_unlocked: Option<bool>Whether the current steps for the achievement has reached the number of steps required to unlock.