pub struct AchievementUpdateResponse {
pub achievement_id: Option<String>,
pub current_state: Option<String>,
pub current_steps: Option<i32>,
pub kind: Option<String>,
pub newly_unlocked: Option<bool>,
pub update_occurred: Option<bool>,
}Expand description
An updated achievement.
This type is not used in any activity, and only used as part of another schema.
Fields
achievement_id: Option<String>The achievement this update is was applied to.
current_state: Option<String>The current state of the achievement.
current_steps: Option<i32>The current steps recorded for this achievement if it is incremental.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#achievementUpdateResponse.
newly_unlocked: Option<bool>Whether this achievement was newly unlocked (that is, whether the unlock request for the achievement was the first for the player).
update_occurred: Option<bool>Whether the requested updates actually affected the achievement.