pub struct CategoryListResponse {
pub items: Option<Vec<Category>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
A third party list metagame categories response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list categories by player metagame (response)
Fields
items: Option<Vec<Category>>The list of categories with usage data.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#categoryListResponse.
next_page_token: Option<String>Token corresponding to the next page of results.