pub struct EventDefinitionListResponse {
pub items: Option<Vec<EventDefinition>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
A ListDefinitions response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list definitions events (response)
Fields
items: Option<Vec<EventDefinition>>The event definitions.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#eventDefinitionListResponse.
next_page_token: Option<String>The pagination token for the next page of results.