EventUpdateResponse

Struct EventUpdateResponse 

pub struct EventUpdateResponse {
    pub batch_failures: Option<Vec<EventBatchRecordFailure>>,
    pub event_failures: Option<Vec<EventRecordFailure>>,
    pub kind: Option<String>,
    pub player_events: Option<Vec<PlayerEvent>>,
}
An event period update resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

batch_failures: Option<Vec<EventBatchRecordFailure>>

Any batch-wide failures which occurred applying updates.

event_failures: Option<Vec<EventRecordFailure>>

Any failures updating a particular event.

kind: Option<String>

Uniquely identifies the type of this resource. Value is always the fixed string games#eventUpdateResponse.

player_events: Option<Vec<PlayerEvent>>

The current status of any updated events