pub struct GeneratePlayGroupingApiTokenResponse {
pub token: Option<PlayGroupingApiToken>,
}Expand description
Response for the GeneratePlayGroupingApiToken RPC.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
token: Option<PlayGroupingApiToken>Token for accessing the Play Grouping API.