pub struct InstanceIosDetails {
pub bundle_identifier: Option<String>,
pub itunes_app_id: Option<String>,
pub kind: Option<String>,
pub preferred_for_ipad: Option<bool>,
pub preferred_for_iphone: Option<bool>,
pub support_ipad: Option<bool>,
pub support_iphone: Option<bool>,
}Expand description
The iOS details resource.
This type is not used in any activity, and only used as part of another schema.
Fields
bundle_identifier: Option<String>Bundle identifier.
itunes_app_id: Option<String>iTunes App ID.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#instanceIosDetails.
preferred_for_ipad: Option<bool>Indicates that this instance is the default for new installations on iPad devices.
preferred_for_iphone: Option<bool>Indicates that this instance is the default for new installations on iPhone devices.
support_ipad: Option<bool>Flag to indicate if this instance supports iPad.
support_iphone: Option<bool>Flag to indicate if this instance supports iPhone.