pub struct InstanceWebDetails {
pub kind: Option<String>,
pub launch_url: Option<String>,
pub preferred: Option<bool>,
}Expand description
The Web details resource.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#instanceWebDetails.
launch_url: Option<String>Launch URL for the game.
preferred: Option<bool>Indicates that this instance is the default for new installations.