pub struct LeaderboardEntry {
pub formatted_score: Option<String>,
pub formatted_score_rank: Option<String>,
pub kind: Option<String>,
pub player: Option<Player>,
pub score_rank: Option<i64>,
pub score_tag: Option<String>,
pub score_value: Option<i64>,
pub time_span: Option<String>,
pub write_timestamp_millis: Option<i64>,
}Expand description
The Leaderboard Entry resource.
This type is not used in any activity, and only used as part of another schema.
Fields
formatted_score: Option<String>The localized string for the numerical value of this score.
formatted_score_rank: Option<String>The localized string for the rank of this score for this leaderboard.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#leaderboardEntry.
player: Option<Player>The player who holds this score.
score_rank: Option<i64>The rank of this score for this leaderboard.
score_tag: Option<String>Additional information about the score. Values must contain no more than 64 URI-safe characters as defined by section 2.3 of RFC 3986.
score_value: Option<i64>The numerical value of this score.
time_span: Option<String>The time span of this high score.
write_timestamp_millis: Option<i64>The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.