pub struct LeaderboardListResponse {
pub items: Option<Vec<Leaderboard>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
A list of leaderboard objects.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list leaderboards (response)
Fields
items: Option<Vec<Leaderboard>>The leaderboards.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#leaderboardListResponse.
next_page_token: Option<String>Token corresponding to the next page of results.