pub struct LeaderboardMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on leaderboard resources.
It is not used directly, but through the Games hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_games1 as games1;
use games1::{Games, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Games::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)` and `list(...)`
// to build up your call.
let rb = hub.leaderboards();Implementations
Sourceimpl<'a, C> LeaderboardMethods<'a, C>
impl<'a, C> LeaderboardMethods<'a, C>
Sourcepub fn get(&self, leaderboard_id: &str) -> LeaderboardGetCall<'a, C>
pub fn get(&self, leaderboard_id: &str) -> LeaderboardGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves the metadata of the leaderboard with the given ID.
Arguments
leaderboardId- The ID of the leaderboard.
Sourcepub fn list(&self) -> LeaderboardListCall<'a, C>
pub fn list(&self) -> LeaderboardListCall<'a, C>
Create a builder to help you perform the following task:
Lists all the leaderboard metadata for your application.