pub struct PlayerAchievement {
pub achievement_state: Option<String>,
pub current_steps: Option<i32>,
pub experience_points: Option<i64>,
pub formatted_current_steps_string: Option<String>,
pub id: Option<String>,
pub kind: Option<String>,
pub last_updated_timestamp: Option<i64>,
}Expand description
An achievement object.
This type is not used in any activity, and only used as part of another schema.
Fields
achievement_state: Option<String>The state of the achievement.
current_steps: Option<i32>The current steps for an incremental achievement.
experience_points: Option<i64>Experience points earned for the achievement. This field is absent for achievements that have not yet been unlocked and 0 for achievements that have been unlocked by testers but that are unpublished.
formatted_current_steps_string: Option<String>The current steps for an incremental achievement as a string.
id: Option<String>The ID of the achievement.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#playerAchievement.
last_updated_timestamp: Option<i64>The timestamp of the last modification to this achievement’s state.