pub struct PlayerEvent {
pub definition_id: Option<String>,
pub formatted_num_events: Option<String>,
pub kind: Option<String>,
pub num_events: Option<i64>,
pub player_id: Option<String>,
}Expand description
An event status resource.
This type is not used in any activity, and only used as part of another schema.
Fields
definition_id: Option<String>The ID of the event definition.
formatted_num_events: Option<String>The current number of times this event has occurred, as a string. The formatting of this string depends on the configuration of your event in the Play Games Developer Console.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#playerEvent.
num_events: Option<i64>The current number of times this event has occurred.
player_id: Option<String>The ID of the player.