pub struct PlayerEventListResponse {
pub items: Option<Vec<PlayerEvent>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
A ListByPlayer response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list by player events (response)
Fields
items: Option<Vec<PlayerEvent>>The player events.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#playerEventListResponse.
next_page_token: Option<String>The pagination token for the next page of results.