pub struct PlayerLeaderboardScore {
pub friends_rank: Option<LeaderboardScoreRank>,
pub kind: Option<String>,
pub leaderboard_id: Option<String>,
pub public_rank: Option<LeaderboardScoreRank>,
pub score_string: Option<String>,
pub score_tag: Option<String>,
pub score_value: Option<i64>,
pub social_rank: Option<LeaderboardScoreRank>,
pub time_span: Option<String>,
pub write_timestamp: Option<i64>,
}Expand description
A player leaderboard score object.
This type is not used in any activity, and only used as part of another schema.
Fields
friends_rank: Option<LeaderboardScoreRank>The rank of the score in the friends collection for this leaderboard.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#playerLeaderboardScore.
leaderboard_id: Option<String>The ID of the leaderboard this score is in.
public_rank: Option<LeaderboardScoreRank>The public rank of the score in this leaderboard. This object will not be present if the user is not sharing their scores publicly.
score_string: Option<String>The formatted value of this score.
score_tag: Option<String>Additional information about the score. Values must contain no more than 64 URI-safe characters as defined by section 2.3 of RFC 3986.
score_value: Option<i64>The numerical value of this score.
The social rank of the score in this leaderboard.
time_span: Option<String>The time span of this score.
write_timestamp: Option<i64>The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.