pub struct ProfileSettings {
pub friends_list_visibility: Option<String>,
pub kind: Option<String>,
pub profile_visible: Option<bool>,
}Expand description
Profile settings
This type is not used in any activity, and only used as part of another schema.
Fields
friends_list_visibility: Option<String>no description provided
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#profileSettings.
profile_visible: Option<bool>Whether the player’s profile is visible to the currently signed in player.