pub struct SnapshotImage {
pub height: Option<i32>,
pub kind: Option<String>,
pub mime_type: Option<String>,
pub url: Option<String>,
pub width: Option<i32>,
}Expand description
An image of a snapshot.
This type is not used in any activity, and only used as part of another schema.
Fields
height: Option<i32>The height of the image.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#snapshotImage.
mime_type: Option<String>The MIME type of the image.
url: Option<String>The URL of the image. This URL may be invalidated at any time and should not be cached.
width: Option<i32>The width of the image.