pub struct SnapshotListResponse {
pub items: Option<Vec<Snapshot>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
A third party list snapshots response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list snapshots (response)
Fields
items: Option<Vec<Snapshot>>The snapshots.
kind: Option<String>Uniquely identifies the type of this resource. Value is always the fixed string games#snapshotListResponse.
next_page_token: Option<String>Token corresponding to the next page of results. If there are no more results, the token is omitted.