pub struct UnlinkPersonaRequest {
pub persona: Option<String>,
pub session_id: Option<String>,
pub token: Option<String>,
}Expand description
Request to remove a Recall token linking PGS principal and an in-game account
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- unlink persona recall (request)
Fields
persona: Option<String>Value of the ‘persona’ field as it was provided by the client in LinkPersona RPC
session_id: Option<String>Required. Opaque server-generated string that encodes all the necessary information to identify the PGS player / Google user and application.
token: Option<String>Value of the Recall token as it was provided by the client in LinkPersona RPC