pub struct UnlinkPersonaResponse {
pub unlinked: Option<bool>,
}Expand description
Response for the UnlinkPersona RPC
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- unlink persona recall (response)
Fields
unlinked: Option<bool>Required. Whether a Recall token specified by the request was deleted. Can be ‘false’ when there were no Recall tokens satisfied the criteria from the request.