pub struct ScopedPlayerIds {
pub developer_player_key: Option<String>,
pub game_player_id: Option<String>,
}Expand description
Scoped player identifiers.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get scoped player ids players (response)
Fields
developer_player_key: Option<String>Identifier of the player across all games of the given developer. Every player has the same developer_player_key in all games of one developer. Developer player key changes for the game if the game is transferred to another developer. Note that game_player_id will stay unchanged.
game_player_id: Option<String>Game-scoped player identifier. This is the same id that is returned in GetPlayer game_player_id field.